import { BOILERPLATE_OPTIONS } from "../../../../constants.js";

export const appTemplate = (
  boilerplate: string[],
  connectorSupports: { visualEditor: boolean; connect: boolean },
) => {
  const hasConnectorBoilerplate = boilerplate.includes(
    BOILERPLATE_OPTIONS.connector,
  );

  return `import { httpBatchLink } from "@trpc/client";
import { QueryClient, QueryClientProvider } from "@tanstack/react-query";
import { Surfaces, useNetlifyExtensionUIFetch } from "@netlify/sdk/ui/react";
import { SurfaceRouter, SurfaceRoute } from "@netlify/sdk/ui/react/components";
import { useState } from "react";
import { SiteConfiguration } from "./surfaces/SiteConfiguration.jsx";
import { TeamConfiguration } from "./surfaces/TeamConfiguration.jsx";
${hasConnectorBoilerplate && connectorSupports.connect ? `import { ConnectConfiguration } from "./surfaces/ConnectConfiguration.js";` : ``}
${hasConnectorBoilerplate && connectorSupports.visualEditor ? `import { VisualEditorConfiguration } from "./surfaces/VisualEditorConfiguration.js";` : ``}
import { trpc } from "./trpc.js";

export const App = () => {
  const fetch = useNetlifyExtensionUIFetch();
  const [queryClient] = useState(() => new QueryClient());
  const [trpcClient] = useState(() =>
    trpc.createClient({
      links: [
        httpBatchLink({
          url: "/api/trpc",
          fetch,
        }),
      ],
    }),
  );

  return (
    <trpc.Provider client={trpcClient} queryClient={queryClient}>
      <QueryClientProvider client={queryClient}>
        <SurfaceRouter>
          <SurfaceRoute surface={Surfaces.SiteConfiguration}>
            <SiteConfiguration />
          </SurfaceRoute>

          <SurfaceRoute surface={Surfaces.TeamConfiguration}>
            <TeamConfiguration />
          </SurfaceRoute>
          ${
            hasConnectorBoilerplate && connectorSupports.connect
              ? `<SurfaceRoute surface={Surfaces.ConnectConfiguration}>
            <ConnectConfiguration />
          </SurfaceRoute>`
              : ``
          }
          ${
            hasConnectorBoilerplate && connectorSupports.visualEditor
              ? `<SurfaceRoute surface={Surfaces.VisualEditorConfiguration}>
            <VisualEditorConfiguration />
          </SurfaceRoute>`
              : ``
          }
        </SurfaceRouter>
      </QueryClientProvider>
    </trpc.Provider>
  );
};
`;
};
